###
## read_file <file>
##    Read the entire contents of a file and return it as a string.
##
##    file - Name of the file to read.
##
## $Id: read_file.tcl 1643517 2014-12-06 10:54:14Z mxmanghi $
##
###

namespace eval ::rivet {

    proc read_file {file args} {

        set fp [open $file]
        if {[llength $args]} { eval fconfigure $fp $args }
        set x [read $fp]
        close $fp
        return $x

    }

}
